@@ -22,12 +22,13 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: All.h 1936 2006-11-06 13:12:06Z svn $
+ * $Id: All.h 1984 2006-11-12 06:43:10Z svn $
  *****************************************************************************/
 
 #ifndef ALL_H
 #define ALL_H
 
+#include "AtomicWrapper.h"
 #include "Auxiliary.h"
 #include "BBSCommentIterator.h"
 #include "BBSCommentVariableCreator.h"
@@ -75,7 +76,6 @@
 #include "WriteLocker.h"
 
 #include "apr.h"
-#include "apr_atomic.h"
 #include "apr_file_info.h"
 #include "apr_file_io.h"
 #include "apr_general.h"
