@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TestRunner.h 1898 2006-10-26 17:46:14Z svn $
+ * $Id: TestRunner.h 1981 2006-11-12 06:40:26Z svn $
  *****************************************************************************/
 
 #ifndef TEST_RUNNER_H
@@ -33,7 +33,7 @@
 #include <iostream>
 #include <iomanip>
 
-#include "apr_atomic.h"
+#include "AtomicWrapper.h"
 #include "apr_file_info.h"
 
 #include "Auxiliary.h"
