@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSThreadManager.cpp 1944 2006-11-07 14:35:58Z svn $
+ * $Id: BBSThreadManager.cpp 1959 2006-11-11 03:05:17Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -48,7 +48,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: BBSThreadManager.cpp 1944 2006-11-07 14:35:58Z svn $");
+SOURCE_INFO_ADD("$Id: BBSThreadManager.cpp 1959 2006-11-11 03:05:17Z svn $");
 
 #ifdef DEBUG
 #include <iostream>
@@ -97,7 +97,7 @@ void BBSThreadManager::init(BBSThreadList *thread_list)
 }
 
 void BBSThreadManager::get_thread_info_sort_by_view(apr_pool_t *pool,
-                                                    apr_size_t *thread_count,
+                                                    apr_uint16_t *thread_count,
                                                     apr_size_t **ids_sort_by_view,
                                                     apr_uint16_t **indexes_sort_by_view) const
 {
@@ -211,7 +211,7 @@ apr_size_t BBSThreadManager::create_thread(const char *subject,
     return thread_id;
 }
 
-apr_size_t BBSThreadManager::add_comment(apr_size_t thread_id,
+apr_uint16_t BBSThreadManager::add_comment(apr_size_t thread_id,
                                          const char *name, const char *trip,
                                          const char *email,
                                          const char *message,
@@ -266,7 +266,7 @@ apr_size_t BBSThreadManager::add_comment(apr_size_t thread_id,
 
 void BBSThreadManager::sync_all_thread()
 {
-    for (apr_size_t i = 0; i < *thread_count_; i++) {
+    for (apr_uint16_t i = 0; i < *thread_count_; i++) {
         write_thread(get_thread_by_index(i, false));
     }
 }
@@ -306,7 +306,7 @@ apr_size_t BBSThreadManager::get_memory_size()
         (BBSThread::MAX_THREAD_DATA_SIZE + sizeof(apr_size_t)
          + sizeof(apr_uint16_t) + sizeof(apr_uint16_t) + sizeof(apr_atomic_t)) *
         MGR_ON_MEMORY_THREAD_COUNT +
-        sizeof(apr_size_t) + sizeof(apr_atomic_t);
+        sizeof(apr_uint16_t) + sizeof(apr_atomic_t);
 }
 
 void BBSThreadManager::check_finalize_state(BBSThreadManager *thread_manager)
@@ -361,12 +361,12 @@ void BBSThreadManager::init_shm()
 
     manager_ref_count_ = AS_ATOMIC(indexes_sort_by_mtime_ + MGR_ON_MEMORY_THREAD_COUNT);
     threads_ref_count_ = manager_ref_count_ + 1;
-    thread_count_ = AS_SIZE(threads_ref_count_ + MGR_ON_MEMORY_THREAD_COUNT);
+    thread_count_ = AS_UINT16(threads_ref_count_ + MGR_ON_MEMORY_THREAD_COUNT);
 
 #ifdef __INTEL_COMPILER
 #pragma warning(disable:1684)
 #endif
-    ASSERT_EQUAL(AS_CHAR(thread_count_) + 4,
+    ASSERT_EQUAL(AS_CHAR(thread_count_) + sizeof(*thread_count_),
                  AS_CHAR(threads_) +
                  (get_memory_size() - sizeof(BBSThreadManager)));
 #ifdef __INTEL_COMPILER
@@ -383,7 +383,7 @@ void BBSThreadManager::init_threads()
 {
     TemporaryPool temp_pool(pool_);
 
-    for (apr_size_t i = 0; i < MGR_ON_MEMORY_THREAD_COUNT; i++) {
+    for (apr_uint16_t i = 0; i < MGR_ON_MEMORY_THREAD_COUNT; i++) {
         new(get_thread_by_index(i, false)) BBSThread;
     }
 
@@ -401,7 +401,7 @@ void BBSThreadManager::init_threads()
         indexes_sort_by_mtime_[i] = NULL_INDEX;
     }
 
-    for (apr_size_t i = 0; i < *thread_count_; i++) {
+    for (apr_uint16_t i = 0; i < *thread_count_; i++) {
         thread_reader_.read(ids_sort_by_view_[i],
                             get_thread_by_index(i, false));
 
@@ -483,9 +483,10 @@ inline apr_uint16_t BBSThreadManager::get_index_by_thread(BBSThread *bbs_thread)
 #pragma warning(push)
 #pragma warning(disable:1684)
 #endif
-    i = (reinterpret_cast<apr_size_t>(bbs_thread) -
-         reinterpret_cast<apr_size_t>(threads_)) >>
-        BBSThread::MAX_THREAD_DATA_SHIFT;
+    i = static_cast<apr_uint16_t>
+        ((reinterpret_cast<apr_size_t>(bbs_thread) -
+          reinterpret_cast<apr_size_t>(threads_)) >>
+         BBSThread::MAX_THREAD_DATA_SHIFT);
 #ifdef __INTEL_COMPILER
 #pragma warning(pop)
 #endif
@@ -525,11 +526,16 @@ void BBSThreadManager::exec_add_comment(BBSThread *bbs_thread,
         update_indexes_sort_by_view(i, bbs_thread->get_id(), is_insert);
     }
 
+#ifdef WIN32
+    // 何かとトラブル(と誤解)を招きそうなので，Windows の場合は毎回書き出す
+    write_thread(bbs_thread);
+#else
     // 未同期のコメントの数が一定値以上になったら書き出す
     if (UNLIKELY(bbs_thread->get_unsynced_comment_count() >
                  MGR_UNSYNCED_COMMENT_LIMIT)) {
         write_thread(bbs_thread);
     }
+#endif
 }
 
 apr_uint16_t BBSThreadManager::read_and_add_comment(apr_size_t thread_id,
@@ -666,7 +672,7 @@ void BBSThreadManager::update_array(T *array, T i, bool is_insert)
     array[0] = i;
 }
 
-int BBSThreadManager::cmp_indexes_by_mtime(apr_size_t left, apr_size_t right) const
+int BBSThreadManager::cmp_indexes_by_mtime(apr_uint16_t left, apr_uint16_t right) const
 {
     // NULL_INDEX の場合の処理
     if ((indexes_sort_by_mtime_[left] == NULL_INDEX) &&
@@ -689,12 +695,13 @@ int BBSThreadManager::cmp_indexes_by_mtime(apr_size_t left, apr_size_t right) co
     }
 }
 
-void BBSThreadManager::sort_indexes_by_mtime(apr_size_t left, apr_size_t right)
+void BBSThreadManager::sort_indexes_by_mtime(apr_uint16_t left,
+                                             apr_uint16_t right)
 {
-    apr_size_t pivot;
-    apr_size_t left_right;
-    apr_size_t right_left;
-    apr_size_t temp;
+    apr_uint16_t pivot;
+    apr_uint16_t left_right;
+    apr_uint16_t right_left;
+    apr_uint16_t temp;
 
     // 比較関数の中で threads_ を参照したかったので，クイックソートをコー
     // ディング
@@ -824,7 +831,7 @@ static void run_read_by_id(apr_pool_t *pool, BBSThreadManager *thread_manager,
 
 static void run_all_read(apr_pool_t *pool, BBSThreadManager *thread_manager)
 {
-    apr_size_t thread_count;
+    apr_uint16_t thread_count;
     apr_size_t *ids_sort_by_view;
     apr_uint16_t *indexes_sort_by_view;
 
