@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostDataChecker.cpp 1884 2006-10-22 10:36:58Z svn $
+ * $Id: PostDataChecker.cpp 1937 2006-11-07 11:45:41Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -35,13 +35,12 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostDataChecker.cpp 1884 2006-10-22 10:36:58Z svn $");
+SOURCE_INFO_ADD("$Id: PostDataChecker.cpp 1937 2006-11-07 11:45:41Z svn $");
 
 /******************************************************************************
  * public メソッド
  *****************************************************************************/
-void PostDataChecker::validate_thread(const char *subject,
-                                      BBSThread::image_t *image)
+void PostDataChecker::validate_thread(const char *subject)
 {
     if (strlen(subject) == 0) {
         THROW(MESSAGE_POST_SUBJECT_EMPTY);
@@ -52,7 +51,7 @@ void PostDataChecker::validate_thread(const char *subject,
 
 void PostDataChecker::validate_comment(const char *name, const char *trip,
                                        const char *email, const char *message,
-                                       bool is_age,
+                                       BBSThread::image_t *image, bool is_age,
                                        BBSThread::bbs_comment_flag_t *flag)
 {
     if (strlen(name) == 0) {
